@@ -1,8 +1,8 @@
 #==========================================================================
 # iplots - interactive plots for R
-# Package version: 1.1-1
+# Package version: 1.1-2
 #
-# $Id: iplots.R 147 2007-09-07 16:54:57Z urbanek $
+# $Id: iplots.R 150 2007-10-16 14:18:51Z urbanek $
 # (C)Copyright 2003-7 Simon Urbanek, 2006 Tobias Wichtrey
 # Authors: Simon Urbanek, Tobias Wichtrey, Alex Gouberman
 #
@@ -253,6 +253,21 @@ iplot.location <- function(x, y, relative=FALSE, plot=iplot.cur()) {
     } else stop("invalid plot")
 }
 
+iplot.size<-function(width, height, plot=iplot.cur()) {
+    if (is.numeric(plot))
+        plot <- .iplots[[plot]]
+    query <- (missing(width) && missing(height))
+    if (inherits(plot, "iplot")) {
+        width <- if (missing(width)) .jcall(plot$obj,"I","getWidth") else as.integer(width)[1]
+        height <- if (missing(height)) .jcall(plot$obj,"I","getHeight") else as.integer(height)[1]
+        if (!query) {
+            .jcall(plot$obj,,"setSize", width, height)
+            .jcall(.jcall(plot$obj,"Ljava/awt/Frame;","getFrame"),,"pack")
+        }
+        c(width=width, height=height)
+    } else stop("invalid plot")
+}
+
 iset <- function(which=iset.cur()) {
   if (!is.numeric(which)) {
     which <- .jcall(.iplots.fw, "I", "getSetIdByName", as.character(which)[1])
